@@ -502,7 +502,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
       for (p = longopts, option_index = 0; p->name; p++, option_index++)
 	if (!strncmp (p->name, nextchar, nameend - nextchar))
 	  {
-	    if (nameend - nextchar == (unsigned int) strlen (p->name))
+	    if ((unsigned int)(nameend - nextchar) == (unsigned int) strlen (p->name))
 	      {
 		/* Exact match found.  */
 		pfound = p;
